==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/creaprezzi.php <==
<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Insert the prices for year"; break;
case "Prezzi della":  				$messaggio = "Prices of"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "soprannominata":  			$messaggio = "called"; break;
case "Dal":  					$messaggio = "From"; break;
case "al":  					$messaggio = "to"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "insert the new prices"; break;
case "modifica i prezzi gi inseriti":  	$messaggio = "modify already inserted prices"; break;
case "Costi aggiuntivi":  			$messaggio = "Extra costs"; break;
case "Costo aggiuntivo di <b>fine locazione</b> soprannominato":	$messaggio = "<b>Single</b> extra cost called"; break;
case "da applicare":  				$messaggio = "to apply"; break;
case "sempre":  				$messaggio = "always"; break;
case "su richiesta":  				$messaggio = "on demand"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "ask by how much it must be multiplied"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "consider this single cost as an extra bed(s)"; break;
case "Costo aggiuntivo <b>settimanale</b> soprannominato":	$messaggio = "<b>Weekly</b> extra cost called"; break;
case "Costo aggiuntivo <b>giornaliero</b> soprannominato":	$messaggio = "<b>Daily</b> extra cost called"; break;
case "numero di settimane":  			$messaggio = "number of weeks"; break;
case "numero di giorni":  			$messaggio = "number of days"; break;
case "tutte":  					$messaggio = "all"; break;
case "tutti":  					$messaggio = "all"; break;
case "tutte meno una":  			$messaggio = "all minus one"; break;
case "tutti meno uno":  			$messaggio = "all minus one"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "consider this weekly cost as an extra bed(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "consider this daily cost as an extra bed(s)"; break;
case "Costo aggiuntivo <b>percentuale</b> soprannominato":	$messaggio = "<b>Percentage</b> extra cost called"; break;
case "della tariffa arrotondato a":  		$messaggio = "of the fare rounded to"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "consider this percentage cost as an extra bed(s)"; break;
case "Inserisci i nuovi costi aggiuntivi":	$messaggio = "Insert the new extra costs"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "La caparra normale  del":  		$messaggio = "The normal deposit is"; break;
case "arrotondata a":  				$messaggio = "rounded to"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Insert or modify the deposit"; break;
case "Vedi i prezzi gi inseriti":  		$messaggio = "View the prices already inserted"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Si deve inserire la percentuale":  	$messaggio = "You must insert the percentage"; break;
case "La caparra  stata modificata":  		$messaggio = "The deposit has been modified"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "You must choose how to apply the single cost"; break;
case "Si deve inserire il nome del costo aggiuntivo finale":	$messaggio = "You must insert the name of the single extra cost"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "The single extra cost"; break;
case "gi esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "already exists, go to the page with the periods and the fares to delete it"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale deve essere applicato su richiesta":	$messaggio = "to ask by how much it must be multiplied the single extra cost must be applied on demand"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "You must choose how to apply the weekly cost"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "You must choose how to apply the daily cost"; break;
case "e il numero di settimane":  		$messaggio = "and the number of weeks"; break;
case "e il numero di giorni":  			$messaggio = "and the number of days"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale deve essere applicato su richiesta":	$messaggio = "to ask the number of weeks or by how much it must be multiplied the weekly extra cost must be applied on demand"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero deve essere applicato su richiesta":	$messaggio = "to ask the number of days or by how much it must be multiplied the daily extra cost must be applied on demand"; break;
case "Si deve inserire il nome del costo aggiuntivo settimanale":	$messaggio = "You must insert the name of the weekly extra cost"; break;
case "Si deve inserire il nome del costo aggiuntivo giornaliero":	$messaggio = "You must insert the name of the daily extra cost"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "You must choose how to apply the percentage cost"; break;
case "e il valore dell'arrotondamento":		$messaggio = "and the value to round to"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale deve essere applicato su richiesta":	$messaggio = "to ask by how much it must be multiplied the percentage extra cost must be applied on demand"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "The percentage extra cost"; break;
case " stato inserito":  			$messaggio = "has been iserted"; break;
case "Nessun dato  stato inserito":  		$messaggio = "No data has been inserted"; break;
case "Si deve inserire il nome del costo aggiuntivo percentuale":	$messaggio = "You must insert the name of the percentage extra cost"; break;
case "Il soprannome della":  			$messaggio = "The name of"; break;
case "gi esiste, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it, or don't insert it to insert prices in new periods"; break;
case "Il soprannome":  				$messaggio = "The name"; break;
case "gi esiste, ne devi usare un'altro":  	$messaggio = "already exists, you must use another one"; break;
case "Le date del periodo numero":  		$messaggio = "The dates of period number"; break;
case "sono sbagliate":  			$messaggio = "are wrong"; break;
case "Il periodo":  				$messaggio = "The period"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "overlaps on another period"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "A price in the period number"; break;
case "esiste gi, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it"; break;
case " stato cambiato":  			$messaggio = "has been changed"; break;
case "Il prezzo del periodo":  			$messaggio = "The price of period"; break;
case " stato inserito":  			$messaggio = "has been inserted"; break;
case "Il prezzo del periodo numero":  		$messaggio = "The price of period number"; break;
case " sbagliato":  				$messaggio = "is wrong"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "The money for single cost is wrong"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "The money for weekly cost is wrong"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "The money for daily cost is wrong"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "The money for percentage cost is wrong"; break;
case "Inserzione per giorni":  			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "Settimane dal":  				$messaggio = "Weeks from"; break;
case "Dom/Lun":  				$messaggio = "Sun/Mon"; break;
case "Lun/Mar":  				$messaggio = "Mon/Tue"; break;
case "Mar/Mer":  				$messaggio = "Tue/Wed"; break;
case "Mer/Gio":  				$messaggio = "Wed/Thu"; break;
case "Gio/Ven":  				$messaggio = "Thu/Fri"; break;
case "Ven/Sab":  				$messaggio = "Fri/Sat"; break;
case "Sab/Dom":  				$messaggio = "Sat/Sun"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Il formato dei soldi  sbagliato":  	$messaggio = "Money format is wrong"; break;
case "I prezzi per le settimane dal":  		$messaggio = "The prices for weeks from"; break;
case "della <b>tariffa":  			$messaggio = "of <b>fare"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/creaprezzi.php <==
<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Insert the prices for year"; break;
case "Prezzi della":  				$messaggio = "Prices of"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "soprannominata":  			$messaggio = "called"; break;
case "Dal":  					$messaggio = "From"; break;
case "al":  					$messaggio = "to"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "insert the new prices"; break;
case "modifica i prezzi gi inseriti":  	$messaggio = "modify already inserted prices"; break;
case "Costi aggiuntivi":  			$messaggio = "Extra costs"; break;
case "Costo aggiuntivo di <b>fine locazione</b> soprannominato":	$messaggio = "<b>Single</b> extra cost called"; break;
case "da applicare":  				$messaggio = "to apply"; break;
case "sempre":  				$messaggio = "always"; break;
case "su richiesta":  				$messaggio = "on demand"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "ask by how much it must be multiplied"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "consider this single cost as an extra bed(s)"; break;
case "Costo aggiuntivo <b>settimanale</b> soprannominato":	$messaggio = "<b>Weekly</b> extra cost called"; break;
case "Costo aggiuntivo <b>giornaliero</b> soprannominato":	$messaggio = "<b>Daily</b> extra cost called"; break;
case "numero di settimane":  			$messaggio = "number of weeks"; break;
case "numero di giorni":  			$messaggio = "number of days"; break;
case "tutte":  					$messaggio = "all"; break;
case "tutti":  					$messaggio = "all"; break;
case "tutte meno una":  			$messaggio = "all minus one"; break;
case "tutti meno uno":  			$messaggio = "all minus one"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "consider this weekly cost as an extra bed(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "consider this daily cost as an extra bed(s)"; break;
case "Costo aggiuntivo <b>percentuale</b> soprannominato":	$messaggio = "<b>Percentage</b> extra cost called"; break;
case "della tariffa arrotondato a":  		$messaggio = "of the fare rounded to"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "consider this percentage cost as an extra bed(s)"; break;
case "Inserisci i nuovi costi aggiuntivi":	$messaggio = "Insert the new extra costs"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "La caparra normale per la":  		$messaggio = "The normal deposit for"; break;
case "arrotondata a":  				$messaggio = "rounded to"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Insert or modify the deposit"; break;
case "Vedi i prezzi gi inseriti":  		$messaggio = "View the prices already inserted"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Si deve inserire la percentuale":  	$messaggio = "You must insert the percentage"; break;
case "La caparra  stata modificata":  		$messaggio = "The deposit has been modified"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "You must choose how to apply the single cost"; break;
case "Si deve inserire il nome del costo aggiuntivo finale":	$messaggio = "You must insert the name of the single extra cost"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "The single extra cost"; break;
case "gi esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "already exists, go to the page with the periods and the fares to delete it"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "To ask by how much it must be multiplied the single extra cost must not be applied automatically"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "You must choose how to apply the weekly cost"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "You must choose how to apply the daily cost"; break;
case "e il numero di settimane":  		$messaggio = "and the number of weeks"; break;
case "e il numero di giorni":  			$messaggio = "and the number of days"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "To ask the number of weeks or by how much it must be multiplied the weekly extra cost must not be applied automatically"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "To ask the number of days or by how much it must be multiplied the daily extra cost must not be applied automatically"; break;
case "Si deve inserire il nome del costo aggiuntivo settimanale":	$messaggio = "You must insert the name of the weekly extra cost"; break;
case "Si deve inserire il nome del costo aggiuntivo giornaliero":	$messaggio = "You must insert the name of the daily extra cost"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "You must choose how to apply the percentage cost"; break;
case "e il valore dell'arrotondamento":		$messaggio = "and the value to round to"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "To ask by how much it must be multiplied the percentage extra cost must not be applied automatically"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "The percentage extra cost"; break;
case " stato inserito":  			$messaggio = "has been inserted"; break;
case "Nessun dato  stato inserito":  		$messaggio = "No data has been inserted"; break;
case "Si deve inserire il nome del costo aggiuntivo percentuale":	$messaggio = "You must insert the name of the percentage extra cost"; break;
case "Il soprannome della":  			$messaggio = "The name of"; break;
case "gi esiste, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it, or don't insert it to insert prices in new periods"; break;
case "Il soprannome":  				$messaggio = "The name"; break;
case "gi esiste, ne devi usare un'altro":  	$messaggio = "already exists, you must use another one"; break;
case "Le date del periodo numero":  		$messaggio = "The dates of period number"; break;
case "sono sbagliate":  			$messaggio = "are wrong"; break;
case "Il periodo":  				$messaggio = "The period"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "overlaps on another period"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "A price in the period number"; break;
case "esiste gi, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it"; break;
case " stato cambiato":  			$messaggio = "has been changed"; break;
case "Il prezzo del periodo":  			$messaggio = "The price of period"; break;
case " stato inserito":  			$messaggio = "has been inserted"; break;
case "Il prezzo del periodo numero":  		$messaggio = "The price of period number"; break;
case " sbagliato":  				$messaggio = "is wrong"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "The money for single cost is wrong"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "The money for weekly cost is wrong"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "The money for daily cost is wrong"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "The money for percentage cost is wrong"; break;
case "Inserzione per giorni":  			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "Settimane dal":  				$messaggio = "Weeks from"; break;
case "Dom/Lun":  				$messaggio = "Sun/Mon"; break;
case "Lun/Mar":  				$messaggio = "Mon/Tue"; break;
case "Mar/Mer":  				$messaggio = "Tue/Wed"; break;
case "Mer/Gio":  				$messaggio = "Wed/Thu"; break;
case "Gio/Ven":  				$messaggio = "Thu/Fri"; break;
case "Ven/Sab":  				$messaggio = "Fri/Sat"; break;
case "Sab/Dom":  				$messaggio = "Sat/Sun"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Il formato dei soldi  sbagliato":  	$messaggio = "Money format is wrong"; break;
case "I prezzi per le settimane dal":  		$messaggio = "The prices for weeks from"; break;
case "della <b>tariffa":  			$messaggio = "of <b>fare"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case " del":  					$messaggio = "is"; break;
case "si":  					$messaggio = "yes"; break;
case "no":  					$messaggio = "no"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "automatically assigned for fares"; break;
case "nessuna":  				$messaggio = "no one"; break;
case "scegliere":  				$messaggio = "choose"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "display in reservation insertion page"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Scegli le tariffe a cui verr applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the fares to which apply automatically the <b>single</b> extra cost"; break;
case "Scegli le tariffe a cui verr applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the fares to which apply automatically the <b>weekly</b> extra cost"; break;
case "Scegli le tariffe a cui verr applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the fares to which apply automatically the <b>daily</b> extra cost"; break;
case "Scegli le tariffe a cui verr applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the fares to which apply automatically the <b>percentage</b> extra cost"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
